Package: nlmeU
Version: 0.71.7
Title: Functions and Data Supporting 'Linear Mixed-Effects Models: A
        Step-by-Step Approach'
Description: Provides functions and datasets to support the book
   by Galecki and Burzykowski (2013),
   'Linear Mixed-Effects Models: A Step-by-Step Approach',
   Springer. Includes functions for power calculations,
   log-likelihood contributions, and data simulation
   for linear mixed-effects models.
Authors@R: c(
   person("Andrzej T.", "Galecki", email = "agalecki@umich.edu", role = c("aut", "cre"), comment = c(ORCID = "0000-0003-1542-4001")),
   person("Tomasz", "Burzykowski", email = "tomasz.burzykowski@uhasselt.be", role = "aut", comment = c(ORCID = "0000-0003-3378-975X"))
   )
Imports: nlme, stats
Suggests: reshape, WWGbook, lattice, ellipse, roxygen2, testthat
Encoding: UTF-8
RoxygenNote: 7.3.2
License: GPL-2
URL: https://github.com/agalecki/nlmeU
Depends: R (>= 3.5.0)
NeedsCompilation: no
Packaged: 2025-08-29 17:11:28 UTC; agalecki
Author: Andrzej T. Galecki [aut, cre] (ORCID:
    <https://orcid.org/0000-0003-1542-4001>),
  Tomasz Burzykowski [aut] (ORCID:
    <https://orcid.org/0000-0003-3378-975X>)
Maintainer: Andrzej T. Galecki <agalecki@umich.edu>
Repository: CRAN
Date/Publication: 2025-08-31 15:20:02 UTC
Built: R 4.6.0; ; 2026-04-26 00:07:14 UTC; unix
