# Generated by roxygen2: do not edit by hand

S3method(Pwr,lme)
S3method(logLik1,lme)
S3method(print,Pwr)
S3method(simulateY,lme)
export(Pwr)
export(SIIdata)
export(armd)
export(armd.wide)
export(armd0)
export(fcat)
export(logLik1)
export(missPat)
export(prt)
export(prt.fiber)
export(prt.subjects)
export(runScript)
export(simulateY)
importFrom(stats,coef)
importFrom(stats,fitted)
importFrom(stats,formula)
importFrom(stats,model.matrix)
importFrom(stats,pf)
importFrom(stats,predict)
importFrom(stats,qf)
importFrom(stats,rnorm)
importFrom(stats,runif)
